==> AsposeCellsCloud-CellsApi-24.3.tar.gz: AsposeCellsCloud-CellsApi-24.3/docs/PptxSaveOptions.md <==
# AsposeCellsCloud::Object::PptxSaveOptions 

## Load the model package
```perl
use AsposeCellsCloud::Object::PptxSaveOptions;
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**IgnoreHiddenRows** | **boolean** |  |
**AdjustFontSizeForRowType** | **string** |  |
**ExportViewType** | **string** |  |
**DefaultFont** | **string** |  |
**CheckWorkbookDefaultFont** | **boolean** |  |
**CheckFontCompatibility** | **boolean** |  |
**IsFontSubstitutionCharGranularity** | **boolean** |  |
**OnePagePerSheet** | **boolean** |  |
**AllColumnsInOnePagePerSheet** | **boolean** |  |
**IgnoreError** | **boolean** |  |
**OutputBlankPageWhenNothingToPrint** | **boolean** |  |
**PageIndex** | **int** |  |
**PageCount** | **int** |  |
**PrintingPageType** | **string** |  |
**GridlineType** | **string** |  |
**TextCrossType** | **string** |  |
**DefaultEditLanguage** | **string** |  |
**EmfRenderSetting** | **string** |  |
**MergeAreas** | **boolean** |  |
**SortExternalNames** | **boolean** |  |
**UpdateSmartArt** | **boolean** |  |
**SaveFormat** | **string** |  |
**CachedFileFolder** | **string** |  |
**ClearData** | **boolean** |  |
**CreateDirectory** | **boolean** |  |
**EnableHTTPCompression** | **boolean** |  |
**RefreshChartCache** | **boolean** |  |
**SortNames** | **boolean** |  |
**ValidateMergedAreas** | **boolean** |  |  

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

==> AsposeCellsCloud-CellsApi-24.5.tar.gz: AsposeCellsCloud-CellsApi-24.5/docs/PptxSaveOptions.md <==
# AsposeCellsCloud::Object::PptxSaveOptions 

## Load the model package
```perl
use AsposeCellsCloud::Object::PptxSaveOptions;
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**IgnoreHiddenRows** | **boolean** | Ignore hidden rows |
**AdjustFontSizeForRowType** | **string** | Adjust font size for row type |
**ExportViewType** | **string** | Gets and sets the display type when exporting to PowerPoint. The default exporting type is working as printing. |
**DefaultFont** | **string** |  |
**CheckWorkbookDefaultFont** | **boolean** |  |
**CheckFontCompatibility** | **boolean** |  |
**IsFontSubstitutionCharGranularity** | **boolean** |  |
**OnePagePerSheet** | **boolean** |  |
**AllColumnsInOnePagePerSheet** | **boolean** |  |
**IgnoreError** | **boolean** |  |
**OutputBlankPageWhenNothingToPrint** | **boolean** |  |
**PageIndex** | **int** |  |
**PageCount** | **int** |  |
**PrintingPageType** | **string** |  |
**GridlineType** | **string** |  |
**TextCrossType** | **string** |  |
**DefaultEditLanguage** | **string** |  |
**EmfRenderSetting** | **string** |  |
**MergeAreas** | **boolean** |  |
**SortExternalNames** | **boolean** |  |
**UpdateSmartArt** | **boolean** |  |
**SaveFormat** | **string** |  |
**CachedFileFolder** | **string** |  |
**ClearData** | **boolean** |  |
**CreateDirectory** | **boolean** |  |
**EnableHTTPCompression** | **boolean** |  |
**RefreshChartCache** | **boolean** |  |
**SortNames** | **boolean** |  |
**ValidateMergedAreas** | **boolean** |  |  

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)
